# Copyright 2024, Seiko Epson Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the “Software”), to deal in
# the Software without restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

from logger.comm import WaitCommand
from logger.measure.A352 import A352, A352ReaderArgs
from logger.measure.job import WriterArgs


class TestA352:
    class TestToReaderArgs:
        def test_to_reader_args(self):
            sensor = A352(
                port="/dev/AAA",
                baud=100,
                product_id="A352XXX",
                sps=1000,
                logger_id="hoge",
                file_rotate_min=1,
            )
            sensor.serial = "test_serial"
            expect = A352ReaderArgs(
                model="A352",
                serial="test_serial",
                port="/dev/AAA",
                baud=100,
                record_size=22,
                record_per_sec=1000,
                start_command=[
                    [0, 0xFF, 0xFF, 0x0D],  # 復帰おまじない3回
                    [0, 0xFF, 0xFF, 0x0D],
                    [0, 0xFF, 0xFF, 0x0D],
                    [0, 0xFE, 0x00, 0x0D],  # WINDOW_ID(L) write command.(WINDOW=0)
                    [0, 0x83, 0x01, 0x0D],  # 自動サンプリングモード
                ],
                end_command=[
                    [0, 0xFE, 0x00, 0x0D],  # Window 0
                    [0, 0x83, 0x02, 0x0D],  # MODE_CTRL: 1-0:10=Config移行
                    WaitCommand(0.01),  # Wait (未指定のためA342に準じる))
                ],
                record_begin=0x80,
                record_end=0x0D,
                count_diff=4,
                count_max=2**16,
                count_start=4,
            )
            assert sensor.to_reader_args() == expect

    class TestToWriterArgs:
        def test_to_writer_args(self):
            sensor = A352(
                port="/dev/AAA",
                baud=100,
                product_id="A352XXX",
                sps=1000,
                logger_id="hoge",
                file_rotate_min=5,
            )
            sensor.serial = "test_serial"
            expect = WriterArgs(
                model="A352",
                serial="test_serial",
                port="/dev/AAA",
                logger_id="hoge",
                record_per_file=1000 * 60 * 5,
            )
            assert sensor.to_writer_args() == expect
